@@ -40,17 +40,20 @@ apastylr.lm <- function(model, term) {
   pvalue <-
     summary_statistics$p.value[1]
   
-  glue::glue("t({df}) = {t}, p {p}",
-             p = ifelse(
-               pvalue < .001,
-               "< .001",
-               sub(
-                 ".",
-                 "= ",
-                 format(round(summary_statistics$p.value, 3),
-                        nsmall = 3
+  as.character(
+    glue::glue("t({df}) = {t}, p {p}",
+               p = ifelse(
+                 pvalue < .001,
+                 "< .001",
+                 sub(
+                   ".",
+                   "= ",
+                   format(round(summary_statistics$p.value, 3),
+                          nsmall = 3
+                   )
                  )
                )
-             ))
+    )
+  )
   
 }
